PCB Environment: Policy Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Public Member Functions | Static Public Member Functions
Policy Class Reference

## Data Structures
struct | CommonParams

## Public Member Functions
virtual uint | decide (const std::vector< float > &)
virtual void | setFastActionMask (uint32_t)
virtual void | setEpsilon (float)
virtual void | setTemperature (float)
virtual float | getEpsilon () const
virtual float | getTemperature () const

## Static Public Member Functions
static Policy * | create (const CommonParams &)

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/RL/Policy.hpp